@@ -16,9 +16,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(COREBACKEND__H)
+#if !defined(KPMCORE_COREBACKEND_H)
 
-#define COREBACKEND__H
+#define KPMCORE_COREBACKEND_H
 
 #include "util/libpartitionmanagerexport.h"
 #include "fs/filesystem.h"
