@@ -29,9 +29,9 @@
 #include "util/report.h"
 
 #include <QRegularExpression>
+#include <QStorageInfo>
 #include <QtMath>
 
-#include <KDiskFreeSpaceInfo>
 #include <KLocalizedString>
 
 /** Constructs a representation of LVM device with initialized LV as Partitions
@@ -53,7 +53,7 @@ LvmDevice::LvmDevice(const QString& vgName, const QString& iconName)
     m_allocPE = m_totalPE - m_freePE;
     m_UUID    = getUUID(vgName);
     m_LVPathList = new QStringList(getLVs(vgName));
-    m_LVSizeMap  = new QMap<QString, qint64>();
+    m_LVSizeMap  = new QHash<QString, qint64>();
 
     initPartitions();
 }
@@ -62,7 +62,7 @@ LvmDevice::LvmDevice(const QString& vgName, const QString& iconName)
  * shared list of PV's paths that will be added to any VGs.
  * (have been added to an operation, but not yet applied)
 */
-QList<const Partition*> LvmDevice::s_DirtyPVs;
+QVector<const Partition*> LvmDevice::s_DirtyPVs;
 
 LvmDevice::~LvmDevice()
 {
@@ -121,7 +121,7 @@ Partition* LvmDevice::scanPartition(const QString& lvPath, PartitionTable* pTabl
     qint64 endSector = startSector + lvSize - 1;
 
     FileSystem::Type type = FileSystem::detectFileSystem(lvPath);
-    FileSystem* fs = FileSystemFactory::create(type, 0, lvSize - 1);
+    FileSystem* fs = FileSystemFactory::create(type, 0, lvSize - 1, logicalSize());
     fs->scan(lvPath);
 
     PartitionRole::Roles r = PartitionRole::Lvm_Lv;
@@ -132,7 +132,7 @@ Partition* LvmDevice::scanPartition(const QString& lvPath, PartitionTable* pTabl
     if (fs->type() == FileSystem::Luks) {
         r |= PartitionRole::Luks;
         FS::luks* luksFs = static_cast<FS::luks*>(fs);
-        luksFs->initLUKS(logicalSize());
+        luksFs->initLUKS();
 
         QString mapperNode = luksFs->mapperName();
         mountPoint = FileSystem::detectMountPoint(fs, mapperNode);
@@ -141,14 +141,13 @@ Partition* LvmDevice::scanPartition(const QString& lvPath, PartitionTable* pTabl
         mountPoint = FileSystem::detectMountPoint(fs, lvPath);
         mounted = FileSystem::detectMountStatus(fs, lvPath);
 
-        // KDiskFreeSpaceInfo does not work with swap
         if (mountPoint != QString() && fs->type() != FileSystem::LinuxSwap) {
-            const KDiskFreeSpaceInfo freeSpaceInfo = KDiskFreeSpaceInfo::freeSpaceInfo(mountPoint);
-            if (logicalSize() > 0 && fs->type() != FileSystem::Luks && mounted && freeSpaceInfo.isValid())
-                fs->setSectorsUsed(freeSpaceInfo.used() / logicalSize());
+            const QStorageInfo storage = QStorageInfo(mountPoint);
+            if (logicalSize() > 0 && fs->type() != FileSystem::Luks && mounted && storage.isValid())
+                fs->setSectorsUsed( (storage.bytesTotal() - storage.bytesFree()) / logicalSize() );
         }
         else if (fs->supportGetUsed() == FileSystem::cmdSupportFileSystem)
-            fs->setSectorsUsed(qCeil(fs->readUsedCapacity(lvPath) / static_cast<float>(logicalSize())));
+            fs->setSectorsUsed(qCeil(fs->readUsedCapacity(lvPath) / static_cast<double>(logicalSize())));
    }
 
     if (fs->supportGetLabel() != FileSystem::cmdSupportNone) {
@@ -251,7 +250,7 @@ const QStringList LvmDevice::getLVs(const QString& vgName)
 qint64 LvmDevice::getPeSize(const QString& vgName)
 {
     QString val = getField(QStringLiteral("vg_extent_size"), vgName);
-    return val.isEmpty() ? -1 : val.toInt();
+    return val.isEmpty() ? -1 : val.toLongLong();
 }
 
 qint64 LvmDevice::getTotalPE(const QString& vgName)
@@ -299,7 +298,7 @@ QString LvmDevice::getField(const QString& fieldName, const QString& vgName)
     if  (!vgName.isEmpty()) {
         args << vgName;
     }
-    ExternalCommand cmd(QStringLiteral("lvm"), args);
+    ExternalCommand cmd(QStringLiteral("lvm"), args, QProcess::ProcessChannelMode::SeparateChannels);
     if (cmd.run(-1) && cmd.exitCode() == 0) {
         return cmd.output().trimmed();
     }
@@ -416,7 +415,7 @@ bool LvmDevice::movePV(Report& report, const QString& pvPath, const QStringList&
     return (cmd.run(-1) && cmd.exitCode() == 0);
 }
 
-bool LvmDevice::createVG(Report& report, const QString vgName, const QList<const Partition*>& pvList, const qint32 peSize)
+bool LvmDevice::createVG(Report& report, const QString vgName, const QVector<const Partition*>& pvList, const qint32 peSize)
 {
     QStringList args = QStringList();
     args << QStringLiteral("vgcreate") << QStringLiteral("--physicalextentsize") << QString::number(peSize);
