@@ -29,12 +29,12 @@
 #include "util/report.h"
 
 #include <QRegularExpression>
+#include <QStorageInfo>
 #include <QString>
 #include <QStringList>
 #include <QTextStream>
 
 #include <KLocalizedString>
-#include <KIOCore/KMountPoint>
 
 /** Creates a new Partition object.
     @param parent the Partition's parent. May be another Partition (for logicals) or a PartitionTable. Must not be nullptr.
@@ -326,17 +326,19 @@ bool Partition::unmount(Report& report)
     if (!isMounted())
         return false;
 
-    bool success = true;
+    bool success = false;
 
-    while (success) {
-        if (fileSystem().canUnmount(deviceNode())) {
-            success = fileSystem().unmount(report, deviceNode());
-        }
+    if (fileSystem().canUnmount(deviceNode())) {
+        success = fileSystem().unmount(report, deviceNode());
+    }
 
-        KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::NeedRealDeviceName);
-
-        if (!mountPoints.findByDevice(deviceNode()))
+    const QString canonicalDeviceNode = QFileInfo(deviceNode()).canonicalFilePath();
+    const QList<QStorageInfo> mountedVolumes = QStorageInfo::mountedVolumes();
+    for (const QStorageInfo &storage : mountedVolumes) {
+        if (QFileInfo(QString::fromUtf8(storage.device())).canonicalFilePath() == canonicalDeviceNode ) {
+            success = false;
             break;
+        }
     }
 
     setMounted(!success);
@@ -389,8 +391,8 @@ QTextStream& operator<<(QTextStream& stream, const Partition& p)
     stream << p.number() << sep
            << p.firstSector() << sep
            << p.lastSector() << sep
-           << p.fileSystem().name() << sep
-           << p.roles().toString() << sep
+           << p.fileSystem().name({ QStringLiteral("C") }) << sep
+           << p.roles().toString({ QStringLiteral("C") }) << sep
            << "\"" << p.fileSystem().label() << QStringLiteral("\"") << sep
            << "\"" << flagList.join(QStringLiteral(",")) << QStringLiteral("\"")
            << "\n";
