@@ -17,6 +17,8 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
+#include "core/fstab.h"
+
 #include "fs/filesystem.h"
 #include "fs/lvm2_pv.h"
 
@@ -29,10 +31,10 @@
 
 #include <blkid/blkid.h>
 
-#include <KMountPoint>
 #include <KLocalizedString>
 
-#include <QDebug>
+#include <QFileInfo>
+#include <QStorageInfo>
 
 const std::array< QColor, FileSystem::__lastType > FileSystem::defaultColorCode =
 {
@@ -62,7 +64,9 @@ const std::array< QColor, FileSystem::__lastType > FileSystem::defaultColorCode
     QColor( 250,230,255 ),
     QColor( 242,155,104 ),
     QColor( 160,210,180 ),
-    QColor( 255,170,0 )
+    QColor( 255,170,0 ),
+    QColor( 170, 120, 255 ),
+    QColor( 177, 82, 69 )
 }
 };
 
@@ -123,19 +127,25 @@ FileSystem::Type FileSystem::detectFileSystem(const QString& partitionPath)
 
 QString FileSystem::detectMountPoint(FileSystem* fs, const QString& partitionPath)
 {
-    QString mountPoint = QString();
+    if (fs->type() == FileSystem::Lvm2_PV)
+        return FS::lvm2_pv::getVGName(partitionPath);
 
-    KMountPoint::List mountPoints = KMountPoint::currentMountPoints(KMountPoint::NeedRealDeviceName);
-    mountPoints.append(KMountPoint::possibleMountPoints(KMountPoint::NeedRealDeviceName));
+    if (partitionPath.isEmpty()) // Happens when during initial scan LUKS is closed
+        return QString();
 
-    if (fs->type() == FileSystem::Lvm2_PV) {
-        mountPoint = FS::lvm2_pv::getVGName(partitionPath);
-    } else {
-        mountPoint = mountPoints.findByDevice(partitionPath) ?
-                     mountPoints.findByDevice(partitionPath)->mountPoint() :
-                     QString();
+    QStringList mountPoints;
+    QFileInfo partitionPathFileInfo(partitionPath);
+    QString partitionCanonicalPath = partitionPathFileInfo.canonicalFilePath();
+    const QList<QStorageInfo> mountedVolumes = QStorageInfo::mountedVolumes();
+    for (const QStorageInfo &storage : mountedVolumes) {
+        if (partitionCanonicalPath == QFileInfo(QString::fromUtf8(storage.device())).canonicalFilePath() ) {
+            mountPoints.append(storage.rootPath());
+        }
     }
-    return mountPoint;
+
+    mountPoints.append(possibleMountPoints(partitionPath));
+
+    return mountPoints.isEmpty() ? QString() : mountPoints.first();
 }
 
 bool FileSystem::detectMountStatus(FileSystem* fs, const QString& partitionPath)
@@ -143,7 +153,7 @@ bool FileSystem::detectMountStatus(FileSystem* fs, const QString& partitionPath)
     bool mounted = false;
 
     if (fs->type() == FileSystem::Lvm2_PV) {
-        mounted = FS::lvm2_pv::getVGName(partitionPath) != QString(); // FIXME: VG name is scanned twice
+        mounted = FS::lvm2_pv::getVGName(partitionPath) != QString();
     } else {
         mounted = isMounted(partitionPath);
     }
@@ -172,6 +182,21 @@ bool FileSystem::create(Report& report, const QString& deviceNode)
     return true;
 }
 
+/** Creates a new FileSystem with a specified Label
+    @param report Report to write status information to
+    @param deviceNode the device node for the Partition to create the FileSystem on
+    @param label the new label for the FileSystem
+    @return true if successful
+*/
+bool FileSystem::createWithLabel(Report& report, const QString& deviceNode, const QString& label)
+{
+    Q_UNUSED(report)
+    Q_UNUSED(deviceNode)
+    Q_UNUSED(label)
+
+    return true;
+}
+
 /** Scans a new FileSystem and load file system specific class variables.
  *  @param deviceNode the device node for the Partition to create the FileSystem on
 */
@@ -366,48 +391,59 @@ qint64 FileSystem::maxCapacity() const
 }
 
 /** @return the maximum label length valid for this FileSystem */
-qint64 FileSystem::maxLabelLength() const
+int FileSystem::maxLabelLength() const
 {
     return 16;
 }
 
-/** @return this FileSystem's type as printable name */
-QString FileSystem::name() const
+/** Validates the label for this FileSystem
+ * @param parent the parent widget passed to the QObject constructor
+ * @return QValidator to validate the file system label line edit input */
+QValidator* FileSystem::labelValidator(QObject *parent) const
 {
-    return nameForType(type());
+    Q_UNUSED(parent)
+    return nullptr;
+}
+
+/** @return this FileSystem's type as printable name */
+QString FileSystem::name(const QStringList& languages) const
+{
+    return nameForType(type(), languages);
 }
 
 /** @return a pointer to a QString C array with all FileSystem names */
-static const QString* typeNames()
+static const KLocalizedString* typeNames()
 {
-    static const QString s[] = {
-        xi18nc("@item filesystem name", "unknown"),
-        xi18nc("@item filesystem name", "extended"),
+    static const KLocalizedString s[] = {
+        kxi18nc("@item filesystem name", "unknown"),
+        kxi18nc("@item filesystem name", "extended"),
 
-        xi18nc("@item filesystem name", "ext2"),
-        xi18nc("@item filesystem name", "ext3"),
-        xi18nc("@item filesystem name", "ext4"),
-        xi18nc("@item filesystem name", "linuxswap"),
-        xi18nc("@item filesystem name", "fat16"),
-        xi18nc("@item filesystem name", "fat32"),
-        xi18nc("@item filesystem name", "ntfs"),
-        xi18nc("@item filesystem name", "reiser"),
-        xi18nc("@item filesystem name", "reiser4"),
-        xi18nc("@item filesystem name", "xfs"),
-        xi18nc("@item filesystem name", "jfs"),
-        xi18nc("@item filesystem name", "hfs"),
-        xi18nc("@item filesystem name", "hfsplus"),
-        xi18nc("@item filesystem name", "ufs"),
-        xi18nc("@item filesystem name", "unformatted"),
-        xi18nc("@item filesystem name", "btrfs"),
-        xi18nc("@item filesystem name", "hpfs"),
-        xi18nc("@item filesystem name", "luks"),
-        xi18nc("@item filesystem name", "ocfs2"),
-        xi18nc("@item filesystem name", "zfs"),
-        xi18nc("@item filesystem name", "exfat"),
-        xi18nc("@item filesystem name", "nilfs2"),
-        xi18nc("@item filesystem name", "lvm2 pv"),
-        xi18nc("@item filesystem name", "f2fs"),
+        kxi18nc("@item filesystem name", "ext2"),
+        kxi18nc("@item filesystem name", "ext3"),
+        kxi18nc("@item filesystem name", "ext4"),
+        kxi18nc("@item filesystem name", "linuxswap"),
+        kxi18nc("@item filesystem name", "fat16"),
+        kxi18nc("@item filesystem name", "fat32"),
+        kxi18nc("@item filesystem name", "ntfs"),
+        kxi18nc("@item filesystem name", "reiser"),
+        kxi18nc("@item filesystem name", "reiser4"),
+        kxi18nc("@item filesystem name", "xfs"),
+        kxi18nc("@item filesystem name", "jfs"),
+        kxi18nc("@item filesystem name", "hfs"),
+        kxi18nc("@item filesystem name", "hfsplus"),
+        kxi18nc("@item filesystem name", "ufs"),
+        kxi18nc("@item filesystem name", "unformatted"),
+        kxi18nc("@item filesystem name", "btrfs"),
+        kxi18nc("@item filesystem name", "hpfs"),
+        kxi18nc("@item filesystem name", "luks"),
+        kxi18nc("@item filesystem name", "ocfs2"),
+        kxi18nc("@item filesystem name", "zfs"),
+        kxi18nc("@item filesystem name", "exfat"),
+        kxi18nc("@item filesystem name", "nilfs2"),
+        kxi18nc("@item filesystem name", "lvm2 pv"),
+        kxi18nc("@item filesystem name", "f2fs"),
+        kxi18nc("@item filesystem name", "udf"),
+        kxi18nc("@item filesystem name", "iso9660"),
     };
 
     return s;
@@ -416,21 +452,21 @@ static const QString* typeNames()
 /** @param t the type to get the name for
     @return the printable name for the given type
 */
-QString FileSystem::nameForType(FileSystem::Type t)
+QString FileSystem::nameForType(FileSystem::Type t, const QStringList& languages)
 {
     Q_ASSERT(t >= 0);
     Q_ASSERT(t < __lastType);
 
-    return typeNames()[t];
+    return typeNames()[t].toString(languages);
 }
 
 /** @param s the name to get the type for
     @return the type for the name or FileSystem::Unknown if not found
 */
-FileSystem::Type FileSystem::typeForName(const QString& s)
+FileSystem::Type FileSystem::typeForName(const QString& s, const QStringList& languages )
 {
     for (quint32 i = 0; i < __lastType; i++)
-        if (typeNames()[i] == s)
+        if (typeNames()[i].toString(languages) == s)
             return static_cast<FileSystem::Type>(i);
 
     return Unknown;
