@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(DUMMYDEVICE__H)
+#if !defined(KPMCORE_DUMMYDEVICE_H)
 
-#define DUMMYDEVICE__H
+#define KPMCORE_DUMMYDEVICE_H
 
 #include "backend/corebackenddevice.h"
 
@@ -30,7 +30,7 @@ class CoreBackendPartitionTable;
 
 class DummyDevice : public CoreBackendDevice
 {
-    Q_DISABLE_COPY(DummyDevice);
+    Q_DISABLE_COPY(DummyDevice)
 
 public:
     DummyDevice(const QString& device_node);
