@@ -49,11 +49,11 @@
 #include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
+#include <QStorageInfo>
 #include <QString>
 #include <QStringList>
 
 #include <KLocalizedString>
-#include <KDiskFreeSpaceInfo>
 #include <KPluginFactory>
 
 #include <parted/parted.h>
@@ -105,21 +105,21 @@ typedef struct _GPTDiskData GPTDiskData;
     @param d the Device in question
     @return the first sector usable by a Partition
 */
-static quint64 firstUsableSector(const Device& d)
+static qint64 firstUsableSector(const Device& d)
 {
     PedDevice* pedDevice = ped_device_get(d.deviceNode().toLatin1().constData());
     PedDisk* pedDisk = pedDevice ? ped_disk_new(pedDevice) : nullptr;
 
-    quint64 rval = 0;
+    qint64 rval = 0;
     if (pedDisk)
-        rval = pedDisk->dev->bios_geom.sectors;
+        rval = static_cast<qint64>(pedDisk->dev->bios_geom.sectors);
 
     if (pedDisk && strcmp(pedDisk->type->name, "gpt") == 0) {
         GPTDiskData* gpt_disk_data = reinterpret_cast<GPTDiskData*>(pedDisk->disk_specific);
         PedGeometry* geom = reinterpret_cast<PedGeometry*>(&gpt_disk_data->data_area);
 
         if (geom)
-            rval = geom->start;
+            rval = static_cast<qint64>(geom->start);
         else
             rval += 32;
     }
@@ -133,16 +133,16 @@ static quint64 firstUsableSector(const Device& d)
     @param d the Device in question
     @return the last sector usable by a Partition
 */
-static quint64 lastUsableSector(const Device& d)
+static qint64 lastUsableSector(const Device& d)
 {
     PedDevice* pedDevice = ped_device_get(d.deviceNode().toLatin1().constData());
     PedDisk* pedDisk = pedDevice ? ped_disk_new(pedDevice) : nullptr;
 
-    quint64 rval = 0;
+    qint64 rval = 0;
     if (pedDisk)
-        rval = static_cast< quint64 >( pedDisk->dev->bios_geom.sectors ) *
-               pedDisk->dev->bios_geom.heads *
-               pedDisk->dev->bios_geom.cylinders - 1;
+        rval = static_cast< qint64 >( pedDisk->dev->bios_geom.sectors ) *
+               static_cast< qint64 >( pedDisk->dev->bios_geom.heads ) *
+               static_cast< qint64 >( pedDisk->dev->bios_geom.cylinders - 1 );
 
     if (pedDisk && strcmp(pedDisk->type->name, "gpt") == 0) {
         GPTDiskData* gpt_disk_data = reinterpret_cast<GPTDiskData*>(pedDisk->disk_specific);
@@ -198,11 +198,9 @@ static qint64 readSectorsUsedLibParted(PedDisk* pedDisk, const Partition& p)
 static void readSectorsUsed(PedDisk* pedDisk, const Device& d, Partition& p, const QString& mountPoint)
 {
     if (!mountPoint.isEmpty() && p.fileSystem().type() != FileSystem::LinuxSwap && p.fileSystem().type() != FileSystem::Lvm2_PV) {
-        const KDiskFreeSpaceInfo freeSpaceInfo = KDiskFreeSpaceInfo::freeSpaceInfo(mountPoint);
-
-        // KDiskFreeSpaceInfo does not work with swap
-        if (p.isMounted() && freeSpaceInfo.isValid())
-            p.fileSystem().setSectorsUsed(freeSpaceInfo.used() / d.logicalSize());
+        const QStorageInfo storage = QStorageInfo(mountPoint);
+        if (p.isMounted() && storage.isValid())
+            p.fileSystem().setSectorsUsed( (storage.bytesTotal() - storage.bytesFree()) / d.logicalSize());
     }
     else if (p.fileSystem().supportGetUsed() == FileSystem::cmdSupportFileSystem)
         p.fileSystem().setSectorsUsed(p.fileSystem().readUsedCapacity(p.deviceNode()) / d.logicalSize());
@@ -336,7 +334,7 @@ void LibPartedBackend::scanDevicePartitions(Device& d, PedDisk* pedDisk)
         if (parent == nullptr)
             parent = d.partitionTable();
 
-        FileSystem* fs = FileSystemFactory::create(type, pedPartition->geom.start, pedPartition->geom.end);
+        FileSystem* fs = FileSystemFactory::create(type, pedPartition->geom.start, pedPartition->geom.end, d.logicalSize());
         fs->scan(partitionNode);
         QString mountPoint;
         bool mounted;
@@ -345,7 +343,7 @@ void LibPartedBackend::scanDevicePartitions(Device& d, PedDisk* pedDisk)
         if (fs->type() == FileSystem::Luks) {
             r |= PartitionRole::Luks;
             FS::luks* luksFs = static_cast<FS::luks*>(fs);
-            luksFs->initLUKS(d.logicalSize());
+            luksFs->initLUKS();
             QString mapperNode = luksFs->mapperName();
             mountPoint = FileSystem::detectMountPoint(fs, mapperNode);
             mounted    = FileSystem::detectMountStatus(fs, mapperNode);
@@ -364,7 +362,7 @@ void LibPartedBackend::scanDevicePartitions(Device& d, PedDisk* pedDisk)
 
         // GPT partitions support partition labels and partition UUIDs
         if(d.partitionTable()->type() == PartitionTable::TableType::gpt)
-            fs->setLabel(fs->readLabel(part->deviceNode()));
+            part->setLabel(QLatin1String(ped_partition_get_name(pedPartition)));
 
         if (fs->supportGetUUID() != FileSystem::cmdSupportNone)
             fs->setUUID(fs->readUUID(part->deviceNode()));
@@ -448,8 +446,8 @@ QList<Device*> LibPartedBackend::scanDevices(bool excludeReadOnly)
             deviceNodes << deviceNode;
         }
 
-        quint32 totalDevices = deviceNodes.length();
-        for (quint32 i = 0; i < totalDevices; ++i) {
+        int totalDevices = deviceNodes.length();
+        for (int i = 0; i < totalDevices; ++i) {
             const QString deviceNode = deviceNodes[i];
 
             emitScanProgress(deviceNode, i * 100 / totalDevices);
@@ -512,6 +510,8 @@ FileSystem::Type LibPartedBackend::detectFileSystem(const QString& partitionPath
             else if (s == QStringLiteral("nilfs2")) rval = FileSystem::Nilfs2;
             else if (s == QStringLiteral("LVM2_member")) rval = FileSystem::Lvm2_PV;
             else if (s == QStringLiteral("f2fs")) rval = FileSystem::F2fs;
+            else if (s == QStringLiteral("udf")) rval = FileSystem::Udf;
+            else if (s == QStringLiteral("iso9660")) rval = FileSystem::Iso9660;
             else
                 qWarning() << "blkid: unknown file system type " << s << " on " << partitionPath;
         }
