@@ -116,7 +116,9 @@ static const struct {
     { FileSystem::Jfs, QStringLiteral("jfs") },
     { FileSystem::Hfs, QStringLiteral("hfs") },
     { FileSystem::HfsPlus, QStringLiteral("hfs+") },
-    { FileSystem::Ufs, QStringLiteral("ufs") }
+    { FileSystem::Ufs, QStringLiteral("ufs") },
+    { FileSystem::Udf, QStringLiteral("ntfs") },
+    { FileSystem::Iso9660, QStringLiteral("iso9660") }
 };
 
 static PedFileSystemType* getPedFileSystemType(FileSystem::Type t)
